@@ -23,7 +23,7 @@ use base qw( Test::Builder::Module Exporter );
 our @EXPORT = qw( create_config_ok create_directory_ok home_directory_ok create_config_helper_ok );
 our @EXPORT_OK = @EXPORT;
 our %EXPORT_TAGS = ( all => \@EXPORT );
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
 my $config_dir;
 
@@ -135,12 +135,15 @@ sub create_config_ok ($;$$)
 {
   my($config_name, $config, $test_name) = @_;
 
+  my $fn = "$config_name.conf";
+  $fn =~ s/::/-/g;
+  
   unless(defined $config)
   {
     my $loader = Mojo::Loader->new;
     my $caller = caller;
     $loader->load($caller);
-    $config = $loader->data($caller, "etc/$config_name.conf");
+    $config = $loader->data($caller, "etc/$fn");
   }
   
   my $tb = __PACKAGE__->builder;  
@@ -152,7 +155,7 @@ sub create_config_ok ($;$$)
     $ok = 0;
   }
   
-  my $config_filename = "$config_dir/$config_name.conf";
+  my $config_filename = "$config_dir/$fn";
   
   eval {
     if(ref $config)
